NAME
Business::Edifact::Message - Class that models Edifact Messages
VERSION
Version 0.07
SYNOPSIS
Parses an individual Edifact message Message objects are instantiated by Business::Edifact::Interchange and an array of them is returned in its messages function $interchange->parse($incoming); my $m_array = $interchange->messages(); for my $msg (@{$m_array}) { ...retrieve message data }
SUBROUTINES/METHODS
new
Called by Business::Edifact::Interchange to instantiate a new Message object. The caller passes the header fields with the reference number identifier and message type
add_segment
Process the next data segment
type
return the message's type e.g. 'QUOTES' or 'ORDERS'
function
Returns the message's function field May be 'original' or 'retransmission'
message_code
Returns 3 character message code from the BGM message
currency_code
reference_number
date_of_message
items
return the list of lineitems
handle_bgm
handle_dtm
NB DTM can occur in different segment groups
handle_pat
handle_rff
handle_cux
handle_nad
handle_lin
handle_pia
handle_imd
handle_qty
handle_gir
handle_moa
handle_tax
handle_alc
handle_rte
handle_loc
handle_pri
handle_uns
handle_cnt
handle_ftx
handle_pcd
clear_item_flags
clear flags at start of new item or summary
AUTHOR
Colin Campbell, <colinsc@cpan.org>
BUGS
Please report any bugs or feature requests to bug-edifact-interchange at rt.cpan.org, or through the web interface at http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Business-Edifact-Interchange. I will be notified, and then you'll automatically be notified of progress on your bug as I make changes.
SUPPORT
You can find documentation for this module with the perldoc command.
perldoc Business::Edifact::Message
ACKNOWLEDGEMENTS
LICENSE AND COPYRIGHT
Copyright 2011-2014 Colin Campbell.
This program is free software; you can redistribute it and/or modify it under the terms of either: the GNU General Public License as published by the Free Software Foundation; or the Artistic License.
See http://dev.perl.org/licenses/ for more information.