NAME

Business::OnlinePayment::TCLink - TrustCommerce backend for Business::OnlinePayment

SYNOPSIS

use Business::OnlinePayment;

my $tx = new Business::OnlinePayment("TCLink");
$tx->content(
    type           => 'VISA',
    login          => '99999',
    password       => '',
    action         => 'Normal Authorization',
    amount         => '49.95',
    first_name     => 'Dan',
    last_name      => 'Helfman',
    address        => '123 Anystreet',
    city           => 'Anywhere',
    state          => 'UT',
    zip            => '84058',
    card_number    => '4111111111111111',
    expiration     => '09/05',
);
$tx->submit();

if($tx->is_success()) {
    print "Card processed successfully: ".$tx->authorization."\n";
} else {
    print "Card was rejected: ".$tx->error_message."\n";
}

SUPPORTED TRANSACTION TYPES

Visa, MasterCard, American Express, Discover, Novus, Diner's Club, Carte Blanche, Japan Card, Enroute, CC

Content required: type, login, password, action, amount, first_name, last_name, card_number, expiration.

Check

Content required: type, login, password, action, amount, first_name, last_name, account_number, routing_code.

DESCRIPTION

For detailed information see Business::OnlinePayment.

NOTE

To settle an authorization-only transaction (where you set action to 'Authorization Only'), submit the transaction id code in the field "order_number" with the action set to "Post Authorization". You can get the transaction id from the authorization by calling the order_number method on the object returned from the authorization. You must also submit the amount field with a value less than or equal to the amount specified in the original authorization.

COMPATIBILITY

This module relies on Net::TCLink for interacting with the TrustCommerce payment engine. See http://www.trustcommerce.com/tclink.html for details.

AUTHOR

Dan Helfman <dan@trustcommerce.com>

Derived from code by Jason Kohles and Ivan Kohler.

SEE ALSO

perl(1). Business::OnlinePayment. Net::TCLink.